package Local::Psi;

use 5.006;
use strict;
use warnings;

our $VERSION = 'this_is_not_a_version';

1;
